@@ -2,8 +2,12 @@
 
 .. rubric:: Functions
 
+.. autofunction:: convert_to_basic_types
+
 .. autofunction:: tuple_to_string
 
+.. autofunction:: unnest
+
 .. rubric:: Submodules
 
 .. autosummary::
@@ -35,11 +39,12 @@
 
 from .version import __version__
 
+from .helper import convert_to_basic_types, tuple_to_string, unnest
 from .data import CCobraData
 from .item import Item
 from .model import CCobraModel
 from .encoder import CCobraTaskEncoder, CCobraResponseEncoder
-from .comparator import CCobraComparator, tuple_to_string
+from .comparator import CCobraComparator
 
 from . import encoders
 from . import benchmark
