@@ -66,7 +66,7 @@ class PlotVisualizer():
         with open(template_path) as file_handle:
             self.template = file_handle.read()
 
-    def get_content_dict(self, result_df, model_log):
+    def get_content_dict(self, result_df, eval_handler, model_log):
         """ Obtain the dictionary mapping from HTML template placeholders
         to content.
 
@@ -74,7 +74,10 @@ class PlotVisualizer():
         ----------
         result_df : pd.DataFrame
             CCOBRA result dataframe.
-            
+
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         model_log : dict(str, dict(str, object))
             Dictionary containing logging information that models supplied via end_participant.
 
@@ -88,17 +91,20 @@ class PlotVisualizer():
 
         raise NotImplementedError()
 
-    def to_html(self, result_df, model_log=None):
+    def to_html(self, result_df, eval_handler, model_log=None):
         """ Fill template with content
 
         Parameters
         ----------
         result_df : pd.DataFrame
             CCOBRA result dataframe.
-            
+
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         model_log : dict(str, dict(str, object))
             Dictionary containing logging information that models supplied via end_participant.
-            
+
         Returns
         -------
         str
@@ -108,21 +114,29 @@ class PlotVisualizer():
         """
 
         # Obtain the template content
-        content_dict = self.get_content_dict(result_df, model_log)
-        
+        content_dict = self.get_content_dict(result_df, eval_handler, model_log)
+
         # If the content dict is empty, the complete section can be skipped
         if content_dict is None:
             return None
 
+        content_dict['PLOT_TYPE'] = eval_handler.data_column
+        content_dict['COMPARATOR'] = eval_handler.comparator.get_name()
+
         # Fill the template and return the resulting HTML
         template = self.template
         for key, value in content_dict.items():
             template = template.replace('{{{{{}}}}}'.format(key), value)
         return template
 
-    def shorttitle(self):
+    def shorttitle(self, eval_handler):
         """ Shorttitle for the visualizer.
 
+        Parameters
+        ----------
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         Returns
         -------
         str
@@ -145,14 +159,17 @@ class AccuracyVisualizer(PlotVisualizer):
 
         super(AccuracyVisualizer, self).__init__('template_accuracy.html')
 
-    def get_content_dict(self, result_df, model_log):
+    def get_content_dict(self, result_df, eval_handler, model_log):
         """ Constructs the template-html mapping dictionary.
 
         Parameters
         ----------
         result_df : pd.DataFrame
             CCOBRA result dataframe.
-            
+
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         model_log : dict(str, dict(str, object))
             Dictionary containing logging information that models supplied via end_participant.
 
@@ -163,8 +180,10 @@ class AccuracyVisualizer(PlotVisualizer):
 
         """
 
+        data_column = "score_{}".format(eval_handler.data_column)
+
         acc_df = result_df.groupby(
-            'model', as_index=False)['hit'].agg(['mean', 'std']).sort_values('mean')
+            'model', as_index=False)[data_column].agg(['mean', 'std']).sort_values('mean')
 
         n_models = len(acc_df.index.tolist())
         alpha = '80'
@@ -180,15 +199,16 @@ class AccuracyVisualizer(PlotVisualizer):
 
         # Compute the explicit ordering
         ordering = result_df.groupby(
-            'model', as_index=False)['hit'].agg('mean').sort_values(
-                'hit', ascending=True)['model'].tolist()
+            'model', as_index=False)[data_column].agg('mean').sort_values(
+                data_column, ascending=True)['model'].tolist()
 
         return {
             'PLOT_DATA': json.dumps(data),
-            'ORDERING': json.dumps(ordering)
+            'ORDERING': json.dumps(ordering),
+            'RANGEMODE': 'nonnegative' if np.all(acc_df['mean'] >= 0) else 'normal'
         }
 
-    def shorttitle(self):
+    def shorttitle(self, eval_handler):
         """ Shorttitle for the visualizer.
 
         Returns
@@ -197,9 +217,8 @@ class AccuracyVisualizer(PlotVisualizer):
             Shorttitle for the visualizer.
 
         """
-
-        return 'Prediction Accuracy'
-
+        return "Bar Plot: {} ({})".format(
+            eval_handler.comparator.get_name(), eval_handler.data_column)
 class BoxplotVisualizer(PlotVisualizer):
     """ Subject-Based boxplot visualizer for the CCOBRA evaluation results.
     Depicts boxplots for predictive accuracies on individuals as well as
@@ -214,14 +233,17 @@ class BoxplotVisualizer(PlotVisualizer):
 
         super(BoxplotVisualizer, self).__init__('template_box.html')
 
-    def get_content_dict(self, result_df, model_log):
+    def get_content_dict(self, result_df, eval_handler, model_log):
         """ Constructs the template-html mapping dictionary.
 
         Parameters
         ----------
         result_df : pd.DataFrame
             CCOBRA result dataframe.
-            
+
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         model_log : dict(str, dict(str, object))
             Dictionary containing logging information that models supplied via end_participant.
 
@@ -231,15 +253,16 @@ class BoxplotVisualizer(PlotVisualizer):
             Returns the content dictionary mapping from template placeholders to html snippets.
 
         """
+        data_column = "score_{}".format(eval_handler.data_column)
 
         subj_df = result_df.groupby(
-            ['model', 'id'], as_index=False)['hit'].agg('mean')
+            ['model', 'id'], as_index=False)[data_column].agg('mean')
         data = []
         n_models = len(subj_df['model'].unique())
 
         for model, model_df in subj_df.groupby('model'):
             data.append({
-                'y': model_df['hit'].tolist(),
+                'y': model_df[data_column].tolist(),
                 'type': 'box',
                 'name': model,
                 'boxpoints': 'all',
@@ -260,15 +283,16 @@ class BoxplotVisualizer(PlotVisualizer):
 
         # Compute the explicit ordering
         ordering = result_df.groupby(
-            'model', as_index=False)['hit'].agg('mean').sort_values(
-                'hit', ascending=True)['model'].tolist()
+            'model', as_index=False)[data_column].agg('mean').sort_values(
+                data_column, ascending=True)['model'].tolist()
 
         return {
             'PLOT_DATA': json.dumps(data),
-            'ORDERING': json.dumps(ordering)
+            'ORDERING': json.dumps(ordering),
+            'RANGEMODE': 'nonnegative' if np.all(model_df[data_column] >= 0) else 'normal'
         }
 
-    def shorttitle(self):
+    def shorttitle(self, eval_handler):
         """ Shorttitle for the visualizer.
 
         Returns
@@ -278,7 +302,7 @@ class BoxplotVisualizer(PlotVisualizer):
 
         """
 
-        return 'Subject-Based Boxplots'
+        return 'Subject-Based Boxplots ({})'.format(eval_handler.data_column)
 
 class MFATableVisualizer(PlotVisualizer):
     """ MFA table visualizer.
@@ -288,14 +312,17 @@ class MFATableVisualizer(PlotVisualizer):
     def __init__(self):
         super(MFATableVisualizer, self).__init__('template_mfa.html', 'template_mfa.css')
 
-    def get_content_dict(self, result_df, model_log):
+    def get_content_dict(self, result_df, eval_handler, model_log):
         """ Constructs the template-html mapping dictionary.
 
         Parameters
         ----------
         result_df : pd.DataFrame
             CCOBRA result dataframe.
-            
+
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         model_log : dict(str, dict(str, object))
             Dictionary containing logging information that models supplied via end_participant.
 
@@ -307,10 +334,7 @@ class MFATableVisualizer(PlotVisualizer):
 
         """
 
-        is_broken = result_df[['task_enc', 'prediction_enc', 'truth_enc']].apply(
-            lambda x: len(x[0]) == len(x[1]) == len(x[2]) == 0, axis=1)
-
-        if np.all(is_broken):
+        if np.any([x not in result_df for x in ['task_enc', 'prediction_enc_response', 'truth_enc_response']]):
             return None
 
         # Construct the MFA dictionary
@@ -318,14 +342,14 @@ class MFATableVisualizer(PlotVisualizer):
         for task, task_df in result_df.groupby('task_enc'):
             mfa_dict[task] = {}
             for model, model_df in task_df.groupby('model'):
-                pred_counts = collections.Counter(model_df['prediction_enc'])
+                pred_counts = collections.Counter(model_df['prediction_enc_response'])
                 pred_max_count = max([x[1] for x in pred_counts.items()])
                 mfa = '<br>'.join(
                     sorted([x[0] for x in pred_counts.items() if x[1] == pred_max_count]))
                 mfa_dict[task][model] = mfa
 
             # Add data MFA
-            truth_counts = collections.Counter(task_df['truth_enc'])
+            truth_counts = collections.Counter(task_df['truth_enc_response'])
             truth_max_count = max([x[1] for x in truth_counts.items()])
             mfa = '<br>'.join(
                 sorted([x[0] for x in truth_counts.items() if x[1] == truth_max_count]))
@@ -340,7 +364,7 @@ class MFATableVisualizer(PlotVisualizer):
                 + 'predictions from the models to each syllogism.'
         }
 
-    def shorttitle(self):
+    def shorttitle(self, eval_handler):
         """ Shorttitle for the visualizer.
 
         Returns
@@ -360,7 +384,7 @@ class SubjectTableVisualizer(PlotVisualizer):
     def __init__(self):
         super(SubjectTableVisualizer, self).__init__('template_subject_table.html', 'template_subject_table.css')
 
-    def get_content_dict(self, result_df, model_log):
+    def get_content_dict(self, result_df, eval_handler, model_log):
         """ Constructs the template-html mapping dictionary.
 
         Parameters
@@ -368,6 +392,12 @@ class SubjectTableVisualizer(PlotVisualizer):
         result_df : pd.DataFrame
             CCOBRA result dataframe.
 
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
+        model_log : dict(str, dict(str, object))
+            Dictionary containing logging information that models supplied via end_participant.
+
         Returns
         -------
         dict(str, str)
@@ -376,18 +406,26 @@ class SubjectTableVisualizer(PlotVisualizer):
 
         """
 
-        is_broken = result_df[['task_enc', 'prediction_enc', 'truth_enc']].apply(
-            lambda x: len(x[0]) == len(x[1]) == len(x[2]) == 0, axis=1)
+        pred_enc_name = "prediction_enc_{}".format(eval_handler.data_column)
+        truth_enc_name = "truth_enc_{}".format(eval_handler.data_column)
 
-        if np.all(is_broken):
+        if np.any([x not in result_df for x in ['task_enc', pred_enc_name, truth_enc_name]]):
+            return None
+
+        if np.all([isinstance(x, float) and np.isnan(x) for x in result_df[pred_enc_name]]):
+            return None
+
+        if np.all([isinstance(x, float) and np.isnan(x) for x in result_df[truth_enc_name]]):
             return None
 
         return {
+            'PRED_ENC_NAME' : pred_enc_name,
+            'TRUTH_ENC_NAME' : truth_enc_name,
             'TEXT': 'The following section shows the results for specific subjects. Please select the subject' \
             + ' identifier using the selection box below.'
         }
 
-    def shorttitle(self):
+    def shorttitle(self, eval_handler):
         """ Shorttitle for the visualizer.
 
         Returns
@@ -397,7 +435,7 @@ class SubjectTableVisualizer(PlotVisualizer):
 
         """
 
-        return 'Subject Results'
+        return "Subject Tables: {}".format(eval_handler.data_column)
 
 class ModelLogVisualizer(PlotVisualizer):
     """ MFA table visualizer.
@@ -407,14 +445,17 @@ class ModelLogVisualizer(PlotVisualizer):
     def __init__(self):
         super(ModelLogVisualizer, self).__init__('template_model_log.html', 'template_model_log.css')
 
-    def get_content_dict(self, result_df, model_log):
+    def get_content_dict(self, result_df, eval_handler, model_log):
         """ Constructs the template-html mapping dictionary.
 
         Parameters
         ----------
         result_df : pd.DataFrame
             CCOBRA result dataframe.
-            
+
+        eval_handler : EvaluationHandler
+            EvaluationHandler objects of the current evaluation
+
         model_log : dict(str, dict(str, object))
             Dictionary containing logging information that models supplied via end_participant.
 
@@ -434,7 +475,7 @@ class ModelLogVisualizer(PlotVisualizer):
             'TEXT' : 'Logged information from the models.'
         }
 
-    def shorttitle(self):
+    def shorttitle(self, eval_handler):
         """ Shorttitle for the visualizer.
 
         Returns
