@@ -11,12 +11,15 @@
 .. autoclass:: Syllogism
     :members:
 
-.. autoclass:: SyllogisticEncoder
+.. autoclass:: SyllogisticTaskEncoder
+    :members:
+.. autoclass:: SyllogisticResponseEncoder
     :members:
 
 """
 
-from .encoder_syl import SyllogisticEncoder
+from .task_encoder_syl import SyllogisticTaskEncoder
+from .resp_encoder_syl import SyllogisticResponseEncoder
 
 from .syllogism import decode_response, encode_response, encode_task, SYLLOGISMS, RESPONSES, \
     Syllogism, VALID_SYLLOGISMS, INVALID_SYLLOGISMS, SYLLOGISTIC_FOL_RESPONSES, dataset_to_matrix
